==> gnustep-back_0.9.5.orig.tar.gz: gnustep-back-0.9.5.orig/Source/gsc/externs.m <==
/* 
   externs.m

   External data

   Copyright (C) 1997 Free Software Foundation, Inc.

   Author:  Adam Fedor <fedor@gnu.org>
   Date: Dec 1998
   
   This file is part of the GNUstep GUI Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/ 

#include <Foundation/NSString.h>

NSString *DPSconfigurationerror = @"DPSconfigurationerror: %@";
NSString *DPSinvalidaccess = @"DPSinvalidaccess: %@";
NSString *DPSinvalidcontext = @"DPSinvalidcontext: %@";
NSString *DPSinvalidexit = @"DPSinvalidexit: %@";
NSString *DPSinvalidfileaccess = @"DPSinvalidfileaccess: %@";
NSString *DPSinvalidfont = @"DPSinvalidfont: %@";
NSString *DPSinvalidid = @"DPSinvalidid: %@";
NSString *DPSinvalidrestore = @"DPSinvalidrestore: %@";
NSString *DPSinvalidparam = @"DPSinvalidparam: %@";
NSString *DPSioerror = @"DPSioerror: %@";
NSString *DPSlimitcheck = @"DPSlimitcheck: %@";
NSString *DPSnocurrentpoint = @"DPSnocurrentpoint: %@";
NSString *DPSnulloutput = @"DPSnulloutput: %@";
NSString *DPSrangecheck = @"DPSrangecheck: %@";
NSString *DPSstackoverflow = @"DPSstackoverflow: %@";
NSString *DPSstackunderflow = @"DPSstackunderflow: %@";
NSString *DPStypecheck = @"DPStypecheck: %@";
NSString *DPSundefined = @"DPSundefined: %@";
NSString *DPSundefinedfilename = @"DPSundefinedfilename: %@";
NSString *DPSundefinedresource = @"DPSundefinedresource: %@";
NSString *DPSundefinedresult = @"DPSundefinedresult: %@";
NSString *DPSunmatchedmark = @"DPSunmatchedmark: %@";
NSString *DPSunregistered = @"DPSunregistered: %@";
NSString *DPSVMerror = @"DPSVMerror: %@";

==> gnustep-back_0.11.0.orig.tar.gz: gnustep-back-0.11.0/Source/gsc/externs.m <==
/* 
   externs.m

   External data

   Copyright (C) 1997 Free Software Foundation, Inc.

   Author:  Adam Fedor <fedor@gnu.org>
   Date: Dec 1998
   
   This file is part of the GNUstep GUI Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/ 

#include <Foundation/NSString.h>

NSString *DPSconfigurationerror = @"DPSconfigurationerror: %@";
NSString *DPSinvalidaccess = @"DPSinvalidaccess: %@";
NSString *DPSinvalidcontext = @"DPSinvalidcontext: %@";
NSString *DPSinvalidexit = @"DPSinvalidexit: %@";
NSString *DPSinvalidfileaccess = @"DPSinvalidfileaccess: %@";
NSString *DPSinvalidfont = @"DPSinvalidfont: %@";
NSString *DPSinvalidid = @"DPSinvalidid: %@";
NSString *DPSinvalidrestore = @"DPSinvalidrestore: %@";
NSString *DPSinvalidparam = @"DPSinvalidparam: %@";
NSString *DPSioerror = @"DPSioerror: %@";
NSString *DPSlimitcheck = @"DPSlimitcheck: %@";
NSString *DPSnocurrentpoint = @"DPSnocurrentpoint: %@";
NSString *DPSnulloutput = @"DPSnulloutput: %@";
NSString *DPSrangecheck = @"DPSrangecheck: %@";
NSString *DPSstackoverflow = @"DPSstackoverflow: %@";
NSString *DPSstackunderflow = @"DPSstackunderflow: %@";
NSString *DPStypecheck = @"DPStypecheck: %@";
NSString *DPSundefined = @"DPSundefined: %@";
NSString *DPSundefinedfilename = @"DPSundefinedfilename: %@";
NSString *DPSundefinedresource = @"DPSundefinedresource: %@";
NSString *DPSundefinedresult = @"DPSundefinedresult: %@";
NSString *DPSunmatchedmark = @"DPSunmatchedmark: %@";
NSString *DPSunregistered = @"DPSunregistered: %@";
NSString *DPSVMerror = @"DPSVMerror: %@";
